==> carbon-components-react-0.5.0.tgz: package/lib/components/Tour/Tour-story.js <==
"use strict";

var _react = _interopRequireDefault(require("react"));

var _react2 = require("@storybook/react");

var _addonKnobs = require("@storybook/addon-knobs");

var _Tour = _interopRequireDefault(require("../Tour"));

var _Button = _interopRequireDefault(require("../Button"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var targets = _react.default.createElement(_react.default.Fragment, null, _react.default.createElement("div", {
  id: "one",
  style: {
    position: 'absolute',
    left: 20,
    top: 20,
    background: 'magenta',
    width: 40,
    height: 40
  }
}), _react.default.createElement(_Button.default, {
  id: "two",
  style: {
    position: 'relative',
    left: 200
  }
}, "I am a button!"), _react.default.createElement("div", {
  id: "four",
  style: {
    position: 'absolute',
    left: 20,
    top: 280,
    background: 'green',
    width: 340,
    height: 40
  }
}), _react.default.createElement("div", {
  id: "five",
  style: {
    position: 'absolute',
    left: -410,
    top: 30,
    background: 'red',
    width: 180,
    height: 180
  }
}), _react.default.createElement("div", {
  id: "six",
  style: {
    position: 'absolute',
    left: 670,
    top: 20,
    background: 'orange',
    width: 40,
    height: 350
  }
}), _react.default.createElement("div", {
  id: "three",
  style: {
    position: 'absolute',
    left: 20,
    top: 1800,
    background: 'orange',
    width: 40,
    height: 40
  }
}));

var steps = {
  default: function _default() {
    return [{
      selector: '#one',
      title: 'Welcome To The Tour',
      description: 'Use this component to point out new or important features.'
    }, {
      selector: '#two',
      movingTarget: true,
      title: 'Interaction',
      description: 'You can interact with the elements being highlighted.'
    }];
  },
  scroll: function scroll() {
    return [{
      selector: '#one',
      title: 'Welcome To The Tour',
      description: 'Use this component to point out new or important features.'
    }, {
      selector: '#three',
      description: 'You can scroll to ofscreen elements'
    }];
  },
  secondaryTargets: function secondaryTargets() {
    return [{
      selector: '#one',
      title: 'Welcome To The Tour',
      description: 'Use this component to point out new or important features.',
      hidePrev: true,
      secondarySelectors: ['#four', '#five']
    }, {
      selector: '#two',
      movingTarget: true,
      title: 'Interaction',
      description: 'You can interact with the elements being highlighted.',
      hideNext: true,
      secondarySelectors: ['#one', '#four', '#six']
    }];
  }
};
(0, _react2.storiesOf)('Pattern|Tour', module).add('default', function () {
  return _react.default.createElement(_react.default.Fragment, null, targets, _react.default.createElement(_Tour.default, {
    steps: steps.default()
  }));
}).add('no mask', function () {
  return _react.default.createElement(_react.default.Fragment, null, targets, _react.default.createElement(_Tour.default, {
    steps: steps.default(),
    disableMask: true
  }));
}).addDecorator(_addonKnobs.withKnobs).add('with scrolling', function () {
  return _react.default.createElement(_react.default.Fragment, null, targets, _react.default.createElement(_Tour.default, {
    steps: steps.scroll(),
    disableAutoScroll: (0, _addonKnobs.boolean)('disable auto scroll', false),
    disableSmoothScroll: (0, _addonKnobs.boolean)('disable smooth scroll', false)
  }));
}).add('hide buttons', function () {
  return _react.default.createElement(_react.default.Fragment, null, targets, _react.default.createElement(_Tour.default, {
    steps: steps.default(),
    hidePrev: true,
    hideNext: true
  }));
}).add('with flip', function () {
  return _react.default.createElement(_react.default.Fragment, null, targets, _react.default.createElement(_Tour.default, {
    enableFlip: true,
    steps: steps.default(),
    flippedTitle: 'Flipped Title',
    flippedDescription: 'Secondary description on the back side of the card. Currently, this is the same for all steps'
  }));
}).add('with secondary selectors and flip before close', function () {
  return _react.default.createElement(_react.default.Fragment, null, targets, _react.default.createElement(_Tour.default, {
    flipBeforeClose: true,
    steps: steps.secondaryTargets(),
    flippedTitle: 'Thanks for touring',
    flippedDescription: 'Secondary description on the back side of the card. Currently, this is the same for all steps'
  }));
});

==> carbon-components-react-0.8.1.tgz: package/lib/components/Tour/Tour-story.js <==
"use strict";

var _react = _interopRequireDefault(require("react"));

var _react2 = require("@storybook/react");

var _addonKnobs = require("@storybook/addon-knobs");

var _Tour = _interopRequireDefault(require("../Tour"));

var _Button = _interopRequireDefault(require("../Button"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var targets = /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement("div", {
  id: "one",
  style: {
    position: 'absolute',
    left: 20,
    top: 20,
    background: 'magenta',
    width: 40,
    height: 40
  }
}), /*#__PURE__*/_react.default.createElement(_Button.default, {
  id: "two",
  style: {
    position: 'relative',
    left: 200
  }
}, "I am a button!"), /*#__PURE__*/_react.default.createElement("div", {
  id: "four",
  style: {
    position: 'absolute',
    left: 20,
    top: 280,
    background: 'green',
    width: 340,
    height: 40
  }
}), /*#__PURE__*/_react.default.createElement("div", {
  id: "five",
  style: {
    position: 'absolute',
    left: -410,
    top: 30,
    background: 'red',
    width: 180,
    height: 180
  }
}), /*#__PURE__*/_react.default.createElement("div", {
  id: "six",
  style: {
    position: 'absolute',
    left: 670,
    top: 20,
    background: 'orange',
    width: 40,
    height: 350
  }
}), /*#__PURE__*/_react.default.createElement("div", {
  id: "three",
  style: {
    position: 'absolute',
    left: 20,
    top: 1800,
    background: 'orange',
    width: 40,
    height: 40
  }
}));

var steps = {
  default: function _default() {
    return [{
      selector: '#one',
      title: 'Welcome To The Tour',
      description: 'Use this component to point out new or important features.'
    }, {
      selector: '#two',
      movingTarget: true,
      title: 'Interaction',
      description: 'You can interact with the elements being highlighted.'
    }];
  },
  withFlipBeforeClose: function withFlipBeforeClose() {
    return [{
      selector: '#one',
      title: 'Welcome To The Tour',
      description: 'Without flipBeforeClose.'
    }, {
      selector: '#two',
      movingTarget: true,
      title: 'Interaction',
      description: 'With flipBeforeClose.',
      flipBeforeClose: true
    }];
  },
  scroll: function scroll() {
    return [{
      selector: '#one',
      title: 'Welcome To The Tour',
      description: 'Use this component to point out new or important features.'
    }, {
      selector: '#three',
      description: 'You can scroll to ofscreen elements'
    }];
  },
  secondaryTargets: function secondaryTargets() {
    return [{
      selector: '#one',
      title: 'Welcome To The Tour',
      description: 'Use this component to point out new or important features.',
      hidePrev: true,
      secondarySelectors: ['#four', '#five']
    }, {
      selector: '#two',
      movingTarget: true,
      title: 'Interaction',
      description: 'You can interact with the elements being highlighted.',
      hideNext: true,
      secondarySelectors: ['#one', '#four', '#six']
    }];
  }
};
(0, _react2.storiesOf)('Pattern|Tour', module).add('default', function () {
  return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, targets, /*#__PURE__*/_react.default.createElement(_Tour.default, {
    steps: steps.default()
  }));
}).add('no mask', function () {
  return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, targets, /*#__PURE__*/_react.default.createElement(_Tour.default, {
    steps: steps.default(),
    disableMask: true
  }));
}).addDecorator(_addonKnobs.withKnobs).add('with scrolling', function () {
  return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, targets, /*#__PURE__*/_react.default.createElement(_Tour.default, {
    steps: steps.scroll(),
    disableAutoScroll: (0, _addonKnobs.boolean)('disable auto scroll', false),
    disableSmoothScroll: (0, _addonKnobs.boolean)('disable smooth scroll', false)
  }));
}).add('hide buttons', function () {
  return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, targets, /*#__PURE__*/_react.default.createElement(_Tour.default, {
    steps: steps.default(),
    hidePrev: true,
    hideNext: true
  }));
}).add('with flip', function () {
  return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, targets, /*#__PURE__*/_react.default.createElement(_Tour.default, {
    enableFlip: true,
    steps: steps.default(),
    flippedTitle: 'Flipped Title',
    flippedDescription: 'Secondary description on the back side of the card. Currently, this is the same for all steps'
  }));
}).add('with flip before close', function () {
  return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, targets, /*#__PURE__*/_react.default.createElement(_Tour.default, {
    steps: steps.withFlipBeforeClose(),
    flippedTitle: 'Flipped Title',
    flippedDescription: 'Secondary description on the back side of the card. Currently, this is the same for all steps'
  }));
}).add('with secondary selectors and flip before close', function () {
  return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, targets, /*#__PURE__*/_react.default.createElement(_Tour.default, {
    flipBeforeClose: true,
    steps: steps.secondaryTargets(),
    flippedTitle: 'Thanks for touring',
    flippedDescription: 'Secondary description on the back side of the card. Currently, this is the same for all steps'
  }));
});
